Stan Math Library: stan/math/prim/scal/fun/inc_beta.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inc_beta.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INC_BETA_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INC_BETA_HPP
3
4 #include <boost/math/special_functions/beta.hpp>
5
6 namespace stan {
7
8 namespace math {
9
10 inline double inc_beta(const double& a,
11 const double& b,
12 const double& x) {
13 using boost::math::ibeta;
14 return ibeta(a, b, x);
15 }
16 }
17 }
18 #endif
stan::math::ibeta
double ibeta(const double a, const double b, const double x)
The normalized incomplete beta function of a, b, and x.
Definition: ibeta.hpp:23
stan
Definition: log_sum_exp.hpp:8
stan::math::inc_beta
fvar< T > inc_beta(const fvar< T > &a, const fvar< T > &b, const fvar< T > &x)
Definition: inc_beta.hpp:20

[ Stan Home Page ] © 2011–2016, Stan Development Team.